Summary: An SSL module for the Apache Web server.
Name: mod_ssl
%define apache_version 1.3.23
%define apache_release 2mdk
Version: 2.8.7
Release: 2.1mdk
%define mm_major 1
%define mm_minor 1.3

Group: System/Servers
URL: http://www.modssl.org
Source0: http://www.modssl.org/source/mod_ssl-%{version}-%{apache_version}.tar.bz2
Source1: mod_ssl.conf
Source2: server.crt
Source3: server.key
Source5: ssl.default-vhost.conf
Source7: gentestcrt.sh
Source8: mod_ssl.conf.ppc
Patch0: ssl.patch.bz2
Patch1: mod_ssl-2.8.2-cca.sh.patch.bz2
License: Apache License
BuildRoot: %{_tmppath}/%{name}-%{version}-buildroot
Prereq: 	apache = %{apache_version} openssl >= 0.9.6
Prereq:		apache-common = %{apache_version}
Prereq:		apache-conf = %{apache_version}
Prereq: 	mm = %{mm_major}.%{mm_minor}

BuildRequires: apache = %{apache_version}
BuildRequires: apache-devel = %{apache_version}, openssl-devel >= 0.9.6
%define sysconfdir /etc
%define apachecontent /var/www/html
%define apachebase %{sysconfdir}/httpd
%define apacheroot /var/www
%define oldapacheroot /home/httpd
%define apachelogs /var/log


%description
The mod_ssl project provides strong cryptography for the Apache 1.3 webserver 
via the Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1) 
protocols by the help of the Open Source SSL/TLS toolkit OpenSSL, which is 
based on SSLeay from Eric A. Young and Tim J. Hudson. 

The mod_ssl package was created in April 1998 by Ralf S. Engelschall and was 
originally derived from software developed by Ben Laurie for use in the 
Apache-SSL HTTP server project. The mod_ssl package is licensed under a 
BSD-style licence, which basically means that you are free to get and use it 
for commercial and non-commercial purposes. 

%prep
%setup -q -n mod_ssl-%{version}-%{apache_version}
%patch1 -p0 -b .cca.sh

cd pkg.sslmod
%patch -p1
cd ../..
pwd
cd mod_ssl-%{version}-%{apache_version} 
perl -pi -e "s|Apache/|Apache-AdvancedExtranetServer/|g;" configure

%build
PATH="$PATH:`pwd`"  SSL_BASE=SYSTEM CFLAGS="`%{_sbindir}/apxs -q CFLAGS`" \
./configure --with-apxs=%{_sbindir}/apxs

### Ugly hack because of conflict between SunOS includes and gcc includes
if [ `uname` = "SunOS" ]; then
   mkdir /tmp/include
   ln -s %{includedir}/openssl/ /tmp/include/openssl
   SSL_INCDIR=/tmp/include CFLAGS_SHLIB="-fPIC -DSHARED_MODULE -DSSL_USE_SDBM" make -e
   rm -rf /tmp/include 
fi
if [ `uname` = "Linux" ]; then
   CFLAGS_SHLIB="-fPIC -DSHARED_MODULE -DSSL_USE_SDBM" make -e
fi

%install

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_libdir}/apache-extramodules
install -m 755 pkg.sslmod/libssl.so \
	$RPM_BUILD_ROOT%{_libdir}/apache-extramodules
mkdir -p $RPM_BUILD_ROOT%{_libdir}/ssl/mod_ssl
install -m 755 pkg.contrib/*.sh $RPM_BUILD_ROOT%{_libdir}/ssl/mod_ssl
install -m 755 %{SOURCE7} $RPM_BUILD_ROOT%{_libdir}/ssl/mod_ssl
mkdir -p $RPM_BUILD_ROOT%{apachebase}/conf/ssl
# install mod_ssl.conf
%ifarch ppc
install -m 644 %{SOURCE8} $RPM_BUILD_ROOT%{apachebase}/conf/ssl/mod_ssl.conf
%else
install -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{apachebase}/conf/ssl
%endif
# install server.crt
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{apachebase}/conf/ssl
# install server.key
install -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{apachebase}/conf/ssl
# install ssl.default-vhost.conf
install -m 644 %{SOURCE5} $RPM_BUILD_ROOT%{apachebase}/conf/ssl

mkdir -p $RPM_BUILD_ROOT%{apachecontent}/addon-modules
pushd $RPM_BUILD_ROOT%{apachecontent}/addon-modules
ln -s ../../../..%{_docdir}/mod_ssl-%{version} mod_ssl-%{version}
popd

%post
if [ $1 = "1" ]; then 
   #We're in Install mode, add module to the config files
   for config in %{apachebase}/conf/{httpd,httpd-perl}.conf; do
     if [ -x %{_sbindir}/advxaddmod -a -e $config ]; then
       %{_sbindir}/advxaddmod $config \
	extramodules/libssl.so mod_ssl.c ssl_module \
	define=HAVE_SSL addconf=conf/ssl/mod_ssl.conf
     fi
     echo "Include  conf/ssl/ssl.default-vhost.conf" >> $config
   done
   #Create a self-signed server key and certificate 
   #this will overwrite the dummy certificate
   echo "Generating self-signed certificate"
   pushd %{apachebase}/conf/ssl/ >/dev/null
   yes ""|%{_libdir}/ssl/mod_ssl/gentestcrt.sh >/dev/null 2>/dev/null
   popd > /dev/null
   if [ -x %{_sbindir}/AESctl ]; then %{_sbindir}/AESctl update;fi 
fi

if [ $1 -gt 1 ]; then 
   #We're in *upgrade mode*. Since we can't be sure the configuration files
   #are sane, remove module from the conf files to clean them, re-add again 
   #in a way that the older module we're replacing won't try to erase (the 
   #post scripts were broken on some packages), and finally clean the module
   #specific config file so it's compatible with the upgrade.
   for config in %{apachebase}/conf/{httpd,httpd-perl}.conf; do
     if [ -x %{_sbindir}/advxdelmod -a -e $config ]; then
       %{_sbindir}/advxdelmod $config \
	extramodules/libssl.so mod_ssl.c ssl_module \
	define=HAVE_SSL addconf=conf/ssl/mod_ssl.conf
       perl -pi -e "s|^#*Include\s+conf/ssl/ssl.default-vhost.conf\n||g;" \
	$config
     fi
     if [ -x %{_sbindir}/advxaddmod -a -e $config ]; then
       %{_sbindir}/advxaddmod $config \
	extramodules/libssl.so mod_ssl.c ssl_module \
	define=HAVE_SSL addconf=conf/ssl/mod_ssl.conf
       echo "Include  conf/ssl/ssl.default-vhost.conf" >> $config
     fi
   done
   if [ -x %{_sbindir}/advxfixconf ]; then
     %{_sbindir}/advxfixconf \
	%{apachebase}/conf/ssl/mod_ssl.conf \
	libssl.so mod_ssl.c ssl_module ifmodule
     %{_sbindir}/advxfixconf \
	%{apachebase}/conf/ssl/ssl.default-vhost.conf \
	libssl.so mod_ssl.c ssl_module ifmodule
   fi
   perl -pi -e "s|file:logs/ssl_mutex|sem|g;" \
	%{apachebase}/conf/ssl/mod_ssl.conf
   #Create a self-signed server key and certificate 
   #this will overwrite the dummy certificate, but will
   #not overwrite a user-generated certificate, since we
   #use config noreplace and it checks the mdsum
   echo "Generating self-signed certificate"
   pushd %{apachebase}/conf/ssl/ > /dev/null
   yes ""|%{_libdir}/ssl/mod_ssl/gentestcrt.sh >/dev/null 2>/dev/null
   popd > /dev/null
   if [ -x %{_sbindir}/AESctl -a ! -e %{_libdir}/apache/libssl.so ]; then 
	%{_sbindir}/AESctl update
   fi 
fi

%postun
if [ $1 = "0" ]; then 
   for config in %{apachebase}/conf/{httpd,httpd-perl}.conf; do
     if [ -x %{_sbindir}/advxdelmod -a -e $config ]; then
       %{_sbindir}/advxdelmod $config \
	extramodules/libssl.so mod_ssl.c ssl_module \
	define=HAVE_SSL addconf=conf/ssl/mod_ssl.conf
       perl -pi -e "s|^#*Include\s+conf/ssl/ssl.default-vhost.conf\n||g;" \
	$config
     fi
   done
   if [ -x %{_sbindir}/AESctl ]; then %{_sbindir}/AESctl update;fi 
fi

%files
%defattr(-,root,root)
%dir %{apachebase}/conf/ssl
%config(noreplace) %{apachebase}/conf/ssl/server.crt
%config(noreplace) %{apachebase}/conf/ssl/server.key
%config(noreplace) %{apachebase}/conf/ssl/mod_ssl.conf
%config(noreplace) %{apachebase}/conf/ssl/ssl.default-vhost.conf
%{apachecontent}/addon-modules/*
%doc pkg.ssldoc/*
%doc ANNOUNCE
%doc CHANGES
%doc CREDITS
%doc LICENSE
%doc NEWS
%doc README
%doc README.GlobalID
%doc README.Support
%doc README.Versions
%doc README.Wishes

%{_libdir}/apache-extramodules/libssl.so

%dir %{_libdir}/ssl/mod_ssl
%{_libdir}/ssl/mod_ssl/*.sh

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Thu Apr 04 2002 Stew Bendict <sbenedict@mandrakesoft.com> 2.8.7-2.1mdk
- alter SSLMutex config for PPC

* Mon Mar 02 2002 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.8.7-2mdk
- Rebuild against apache to ensure 100% EAPI compatibility

* Tue Feb 28 2002 Christian Belisle <cbelisle@mandrakesoft.com> 2.8.7-1mdk
- 2.8.7.

* Mon Feb 04 2002 Christian Belisle <cbelisle@mandrakesoft.com> 2.8.6-1mdk
- 2.8.6.
- Rebuild against latest apache.

* Mon Jan 22 2002 Christian Belisle <cbelisle@mandrakesoft.com> 2.8.5-4mdk
- Rebuild against latest openssl.

* Mon Dec  3 2001 Stefan van der Eijk <stefan@eijk.nu> 2.8.5-3mdk
- Remove %%dir %%{_libdir}/ssl (dir owned by openssl)

* Thu Nov 22 2001 Christian Belisle <cbelisle@mandrakesoft.com> 2.8.5-2mdk
- Fix invalid-packager and no-url warnings (rpmlint).
- apply -q option to setup

* Tue Oct 16 2001 Christian Belisle <cbelisle@mandrakesoft.com> 2.8.5-1mdk
- 2.8.5.
- apache 1.3.22.

* Fri Oct 12 2001 Stefan van der Eijk <stefan@eijk.nu> 2.8.4-3mdk
- BuildRequires: openssl --> openssl-devel
- Replaced entries of RPM SOURCE DIR (make rpmlint happy)

* Tue Sep 04 2001 Christian Belisle <cbelisle@mandrakesoft.com> 2.8.4-2mdk
- rebuild against latest version of OpenSSL.

* Wed Jul 11 2001 Philippe Libat <philippe@mandrakesoft.com> 2.8.4-1mdk
- new version

* Wed May 16 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 2.8.2-6mdk
- Fix cca.sh OpenSSL binary location.

* Sat Apr 14 2001 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.8.2-5mdk
- fixed config with proxied perl

* Fri Apr 13 2001 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.8.2-4mdk
- fixed prereqs
- fixed post script that was too verbose

* Fri Apr 13 2001 David Baudens <baudens@mandrakesoft.com> 2.8.2-3mdk
- Use %_tmppath for BuildRoot (allow build as user)

* Mon Apr  9 2001 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.8.2-2mdk
- removed mod_ssl-sxnet, will be in a separate package
- fixed the post scripts, updates should work now
- got rid of the static server certificate and key, we now generate a
  self-signed test certificate during install (as discussed on the
  security mailing list)
- fix the SSLMutex directive to get rid of the Mutex temporary file
  that "spammed" the error_log.

* Sun Apr 08 2001 Stefan van der Eijk <stefan@eijk.nu> 2.8.2-1mdk
- updated to 2.8.2
- adjusted mod_ssl.patch

* Wed Mar 07 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 2.7.1-3mdk
- Rebuild, a long time request of cookers.

* Tue Oct 24 2000 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.7.1-2mdk
- fixed packager tag

* Sat Oct 21 2000 Jean-Michel Dailt <jmdault@mandrakesoft.com> 2.7.1-1mdk
- bugfix release for apache bugfix and security release

* Thu Aug 24 2000 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.6.6-1mdk
- new and shiny 2.6.6

* Wed Aug 09 2000 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.6.5-3mdk
- Fixed ssl.default-vhost.conf for FHS

* Wed Aug 09 2000 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.6.5-2mdk
- Macroize
- FHS compliance
- Now in cooker because there is no cooker-crypto and it depends heavily
  on the openssl version in cooker

* Fri Jul 14 2000 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.6.5-1mdk
- 2.6.5
- use new AESctl for %post scripts

* Mon May 08 2000 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.6.4-1mdk
- 2.6.4 (more bugfixes)

* Mon Apr 17 2000 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.6.3-1mdk
- 2.6.3 (bug fixes)
- re-made documentation

* Sun Apr 02 2000 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.6.2-2mdk
- fixed defattr

* Sun Apr 02 2000 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.6.2-1mdk
- 2.6.2 
- fix group

* Tue Feb 29 2000 Jean-Michel Dault <jmdault@netrevolution.com> 2.6.1-1mdk
- update to 2.6.1

* Mon Feb 28 2000 Jean-Michel Dault <jmdault@netrevolution.com> 2.6.0-3mdk
- added Thawte logo in mod_sxnet documentation

* Sun Feb 27 2000 Jean-Michel Dault <jmdault@netrevolution.com> 2.6.0-2mdk
- fixed segfault in CustomLogs

* Sun Feb 27 2000 Jean-Michel Dault <jmdault@netrevolution.com> 2.6.0-1mdk
- updated to 2.6.0

* Sun Jan 23 2000 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.5.0

* Wed Jan 19 2000 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.4.10

* Mon Jan  3 2000 Jean-Michel Dault <jmdault@netrevolution.com>
- final cleanup for Mandrake 7

* Thu Dec 30 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- rebuilt for Mandrake 7.0

* Sat Dec 12 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.4.9

* Mon Sep 06 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- re-build for mm 1.0.11
- changed post script to stop, then start httpd, instead of restart,
  because it didn't restart cleanly

* Fri Sep 3 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- modified config file
- rebuilt for new mm-1.0.10 module in Apache

* Wed Sep 1 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.4.1

* Wed Aug 18 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.4.0

* Mon Aug 16 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- build for apache 1.3.9

* Sun Aug 15 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.3.11
- cleaned SPEC file, Solaris/UltraSparc adaptation

* Sat Jul 31 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.3.10
- changed postun script

* Thu Jul 29 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- updated again to 2.3.9

* Tue Jul 22 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.3.6
- modified config so Linuxconf could manage it (I hope...)

* Sat Jun 05 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- moved documentation in html
- rebuilt for the new optimized apache

* Sun May 30 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.3.1
- add fr locale
- added sxnet (Secure ExtraNet) package from Thawte

* Sun May 23 1999 Bernhard Rosenkrnzer <bero@mandrakesoft.com>
- handle RPM_OPT_FLAGS
- add de locale
- don't require openssl-devel
